@@ -30,22 +30,6 @@ RESET_SYSTEM_VALUE_MAP = {
 
 RESET_SYSTEM_VALUE_MAP_REV = utils.revert_dictionary(RESET_SYSTEM_VALUE_MAP)
 
-SYSTEM_POWER_STATE_MAP = {
-    'On': sys_cons.SYSTEM_POWER_STATE_ON,
-    'Off': sys_cons.SYSTEM_POWER_STATE_OFF,
-    'PoweringOn': sys_cons.SYSTEM_POWER_STATE_POWERING_ON,
-    'PoweringOff': sys_cons.SYSTEM_POWER_STATE_POWERING_OFF,
-}
-
-SYSTEM_POWER_STATE_MAP_REV = utils.revert_dictionary(SYSTEM_POWER_STATE_MAP)
-
-SYSTEM_INDICATOR_LED_MAP = {
-    'Lit': sys_cons.SYSTEM_INDICATOR_LED_LIT,
-    'Blinking': sys_cons.SYSTEM_INDICATOR_LED_BLINKING,
-    'Off': sys_cons.SYSTEM_INDICATOR_LED_OFF,
-    'Unknown': sys_cons.SYSTEM_INDICATOR_LED_UNKNOWN,
-}
-
 BOOT_SOURCE_TARGET_MAP = {
     'None': sys_cons.BOOT_SOURCE_TARGET_NONE,
     'Pxe': sys_cons.BOOT_SOURCE_TARGET_PXE,
@@ -90,19 +74,66 @@ PROCESSOR_ARCH_VALUE_MAP = {
 PROCESSOR_ARCH_VALUE_MAP_REV = (
     utils.revert_dictionary(PROCESSOR_ARCH_VALUE_MAP))
 
-HEALTH_STATE_VALUE_MAP = {
-    'Enabled': sys_cons.HEALTH_STATE_ENABLED,
-    'Disabled': sys_cons.HEALTH_STATE_DISABLED,
+PROCESSOR_TYPE_VALUE_MAP = {
+    'Accelerator': sys_cons.PROCESSOR_TYPE_ACCELERATOR,
+    'CPU': sys_cons.PROCESSOR_TYPE_CPU,
+    'Core': sys_cons.PROCESSOR_TYPE_CORE,
+    'DSP': sys_cons.PROCESSOR_TYPE_DSP,
+    'FPGA': sys_cons.PROCESSOR_TYPE_FPGA,
+    'GPU': sys_cons.PROCESSOR_TYPE_GPU,
+    'OEM': sys_cons.PROCESSOR_TYPE_OEM,
+    'Thread': sys_cons.PROCESSOR_TYPE_THREAD
 }
 
-HEALTH_STATE_VALUE_MAP_REV = (
-    utils.revert_dictionary(HEALTH_STATE_VALUE_MAP))
+PROCESSOR_TYPE_VALUE_MAP_REV = (
+    utils.revert_dictionary(PROCESSOR_TYPE_VALUE_MAP))
 
-HEALTH_VALUE_MAP = {
-    'OK': sys_cons.HEALTH_OK,
-    'Warning': sys_cons.HEALTH_WARNING,
-    'Critical': sys_cons.HEALTH_CRITICAL
+PROCESSOR_INSTRUCTIONSET_VALUE_MAP = {
+    'ARM-A32': sys_cons.PROCESSOR_INSTRUCTIONSET_ARM_A32,
+    'ARM-A64': sys_cons.PROCESSOR_INSTRUCTIONSET_ARM_A64,
+    'IA-64': sys_cons.PROCESSOR_INSTRUCTIONSET_IA_64,
+    'MIPS32': sys_cons.PROCESSOR_INSTRUCTIONSET_MIPS32,
+    'MIPS64': sys_cons.PROCESSOR_INSTRUCTIONSET_MIPS64,
+    'OEM': sys_cons.PROCESSOR_INSTRUCTIONSET_OEM,
+    'x86': sys_cons.PROCESSOR_INSTRUCTIONSET_x86,
+    'x86-64': sys_cons.PROCESSOR_INSTRUCTIONSET_x86_64
 }
 
-HEALTH_VALUE_MAP_REV = (
-    utils.revert_dictionary(HEALTH_VALUE_MAP))
+PROCESSOR_INSTRUCTIONSET_VALUE_MAP_REV = (
+    utils.revert_dictionary(PROCESSOR_INSTRUCTIONSET_VALUE_MAP))
+
+SYSTEM_TYPE_VALUE_MAP = {
+    'Physical': sys_cons.SYSTEM_TYPE_PHYSICAL,
+    'Virtual': sys_cons.SYSTEM_TYPE_VIRTUAL,
+    'OS': sys_cons.SYSTEM_TYPE_OS,
+    'PhysicallyPartitioned': sys_cons.SYSTEM_TYPE_PHYSICALLY_PARTITIONED,
+    'VirtuallyPartitioned': sys_cons.SYSTEM_TYPE_VIRTUALLY_PARTITIONED,
+    'Composed': sys_cons.SYSTEM_TYPE_COMPOSED
+}
+
+SYSTEM_TYPE_VALUE_MAP_REV = (
+    utils.revert_dictionary(SYSTEM_TYPE_VALUE_MAP))
+
+SECURE_BOOT_STATE = {
+    'Enabled': sys_cons.SECURE_BOOT_ENABLED,
+    'Disabled': sys_cons.SECURE_BOOT_DISABLED,
+}
+
+SECURE_BOOT_STATE_REV = utils.revert_dictionary(SECURE_BOOT_STATE)
+
+SECURE_BOOT_MODE = {
+    'SetupMode': sys_cons.SECURE_BOOT_MODE_SETUP,
+    'UserMode': sys_cons.SECURE_BOOT_MODE_USER,
+    'AuditMode': sys_cons.SECURE_BOOT_MODE_AUDIT,
+    'DeployedMode': sys_cons.SECURE_BOOT_MODE_DEPLOYED,
+}
+
+SECURE_BOOT_MODE_REV = utils.revert_dictionary(SECURE_BOOT_MODE)
+
+SECURE_BOOT_RESET_KEYS = {
+    'ResetAllKeysToDefault': sys_cons.SECURE_BOOT_RESET_KEYS_TO_DEFAULT,
+    'DeleteAllKeys': sys_cons.SECURE_BOOT_RESET_KEYS_DELETE_ALL,
+    'DeletePK': sys_cons.SECURE_BOOT_RESET_KEYS_DELETE_PK,
+}
+
+SECURE_BOOT_RESET_KEYS_REV = utils.revert_dictionary(SECURE_BOOT_RESET_KEYS)
